# Lytils
Python utilities. Pytils was taken.

# To discover unittests in python, use the following command:
python3 -m unittest discover -s tests -p "test_*.py"

# Install optional deps with lytils by doing the following:
poetry add lytils --extras google-sheets
poetry add lytils --extras log-html
